@@ -16,6 +16,9 @@ from . import _class1_check
 from ._class0 import *
 from . import _class1_compute
 from . import _class1_interpolate
+from . import _class1_uniformize
+from . import _export_dataframe
+from . import _find_plateau
 
 
 #############################################
@@ -437,12 +440,29 @@ class DataStock1(DataStock0):
     # General use methods
     ###########
 
-    def to_DataFrame(self, which=None):
-        which, dd = self.__check_which(which, return_dict=True)
-        if which is None:
-            return
-        import pandas as pd
-        return pd.DataFrame(dd)
+    # ---------------------
+    # export methods
+    # ---------------------
+
+    def to_DataFrame(self, which=None, keys=None):
+        """ Export a set of uniform data arrays to a pandas DataFrame
+
+        To be done
+
+        """
+        return _export_dataframe.to_dataframe(
+            coll=self,
+            which=which,
+            keys=keys,
+        )
+
+    def find_plateau(self, keys=None, ref=None):
+        """ Typically used for time-traces, identify plateau phases """
+        return _find_plateau.find_plateau(
+            coll=self,
+            keys=keys,
+            ref=ref,
+        )
 
     # ---------------------
     # Key selection methods
@@ -536,7 +556,140 @@ class DataStock1(DataStock0):
             self._dobj[which] = dd
 
     # ---------------------
-    # Methods interpolating
+    # Getting a common reference vector
+    # ---------------------
+
+    def get_ref_vector(
+        self,
+        # key 
+        key=None,
+        # which ref / dimension
+        ref=None,
+        dim=None,
+        quant=None,
+        name=None,
+        units=None,
+        # nearest-neighbour interpolation input
+        values=None,
+        indices=None,
+        ind_strict=None,
+    ):
+        """ Return the monotonous vector associated to a ref of key
+
+        Typical use: get the time vector of a multidimensional key
+
+        >>> import datastock as ds
+        >>> nt = 11; t0 = np.linspace(0, 10, nt);
+        >>> nx = 21; x = np.linspace(0, 10, nx);
+        >>> xt = np.sin(t0)[:, None] * (x-x.mean())[None, :]
+        >>> st = ds.DataStock()
+        >>> st.add_ref(key='nt', size=nt)
+        >>> st.add_ref(key='nx', size=nx)
+        >>> st.add_data(key='t0', data=t0)
+        >>> st.add_data(key='x', data=x)
+        >>> st.add_data(key='xt', data=xt)
+        >>> hasref, hasvect, ref, key_vect, dind = st.get_ref_vector(key='xt', ref='nt', values=[2, 3, 3.1, 5])
+
+        In the above example:
+            - hasref = True: 'xt' has 'nt' has ref
+            - hasvect = True: there is a monotonous vector with ref 'nt'
+            - ref = 'nt'
+            - key_vect = 't0'
+            - dind = {
+                'key': [2, 3, 3.1, 5],  # the desired time points
+                'ind':  [2, 3, 3, 5],   # the indices of t in t0
+                'indu': [2, 3, 5]       # the unique indices of t in t0
+                'indr': (3, 4),         # bool array showing, for each indu, matching ind
+                'indok': [True, False, ...]
+              }
+
+        """
+
+        return _class1_uniformize.get_ref_vector(
+            # ressources
+            ddata=self._ddata,
+            dref=self._dref,
+            # inputs
+            key=key,
+            ref=ref,
+            dim=dim,
+            quant=quant,
+            name=name,
+            units=units,
+            # parameters
+            values=values,
+            indices=indices,
+            ind_strict=ind_strict,
+        )
+
+    def get_ref_vector_common(
+        self,
+        keys=None,
+        # for selecting ref vector
+        ref=None,
+        dim=None,
+        quant=None,
+        name=None,
+        units=None,
+        # values, indices
+        values=None,
+        indices=None,
+        ind_strict=None,
+    ):
+        """ Return a unique ref vector and a dict of indices
+
+
+        Return
+        ------
+        val:        np.ndarray
+            common finest vector
+        dout:       dict
+            dict of indices, per key, to match val
+
+        """
+
+        return _class1_uniformize.get_ref_vector_common(
+            # ressources
+            ddata=self._ddata,
+            dref=self._dref,
+            # inputs
+            keys=keys,
+            # for selecting ref vector
+            ref=ref,
+            dim=dim,
+            quant=quant,
+            name=name,
+            units=units,
+            # parameters
+            values=values,
+            indices=indices,
+            ind_strict=ind_strict,
+        )
+
+    # ---------------------
+    # Uniformize
+    # ---------------------
+
+    def uniformize(
+        self,
+        keys=None,
+        refs=None,
+        param=None,
+        lparam=None,
+        returnas=None,
+    ):
+
+        return _class1_uniformize.uniformize(
+            coll=self,
+            keys=keys,
+            refs=refs,
+            param=param,
+            lparam=lparam,
+            returnas=returnas,
+        )
+
+    # ---------------------
+    # Interpolation
     # ---------------------
 
     def interpolate(
@@ -556,6 +709,9 @@ class DataStock1(DataStock0):
         log_log=None,
         return_params=None,
     ):
+        """ Interpolate keys in desired dimension
+
+        """
         return _class1_interpolate.interpolate(
             # interpolation base
             keys=keys,
